@@ -96,7 +96,6 @@ define([
             this.name = name;
             this.path = path;
             this.category = category;
-            
 
             this.config = {
                 sizeLevel: 0,          // 0: 400x400 / 1: 500x500 / 2: 600x500 / 3: 750x500
@@ -114,8 +113,9 @@ define([
                 position: { right: 10, top: 120 },
                 size: { width: 400, height: 550 },
                 saveOnly: false, // apply mode
-                checkModules: [] // module aliases or function names
-                , ...restConfig
+                checkModules: [], // module aliases or function names
+                docs: 'https://visual-python.gitbook.io/docs/getting-started/welcome-to-visual-python',
+                ...restConfig
             };
 
             // check BoardFrame width and set initial position of popup
@@ -563,9 +563,13 @@ define([
             let { 
                 installButton, importButton, packageButton, 
                 codeview, dataview, runButton, footer, 
-                sizeLevel, position
+                sizeLevel, position, docs
             } = this.config;
 
+            // apply link to docs
+            if (docs) {
+                $(this.wrapSelector('.vp-popup-docs')).prop('href', docs);
+            }
             // import & package manager button hide/show
             if (!installButton) { // FIXME: Deprecated after creating package manager
                 $(this.wrapSelector('#popupInstall')).hide();
@@ -620,6 +624,9 @@ define([
                 case 3: 
                     this.config.size = { width: 760, height: 550 };
                     break;
+                case 4:
+                    this.config.size = { width: 1064, height: 550 };
+                    break;
             }
 
             // set detailed size
